@@ -1,5 +1,7 @@
-from optimade.models import ReferenceResource
+from typing import Type
+
 from optimade.adapters.base import EntryAdapter
+from optimade.models import ReferenceResource
 
 
 class Reference(EntryAdapter):
@@ -19,4 +21,4 @@ class Reference(EntryAdapter):
 
     """
 
-    ENTRY_RESOURCE: ReferenceResource = ReferenceResource
+    ENTRY_RESOURCE: Type[ReferenceResource] = ReferenceResource
