@@ -10,10 +10,10 @@ from optimade.client.client import OptimadeClient
 __all__ = ("_get",)
 
 
-@click.command("optimade-get")
+@click.command("optimade-get", no_args_is_help=True)
 @click.option(
     "--filter",
-    default=[""],
+    default=[None],
     help="Filter to apply to OPTIMADE API. Default is an empty filter.",
     multiple=True,
 )
@@ -53,6 +53,11 @@ __all__ = ("_get",)
     is_flag=True,
     help="Pretty print the JSON results.",
 )
+@click.option(
+    "--silent",
+    is_flag=True,
+    help="Suppresses all output except the final JSON results.",
+)
 @click.option(
     "--include-providers",
     default=None,
@@ -73,6 +78,11 @@ __all__ = ("_get",)
     default=None,
     nargs=-1,
 )
+@click.option(
+    "--http-timeout",
+    type=float,
+    help="The timeout to use for each HTTP request.",
+)
 def get(
     use_async,
     filter,
@@ -84,9 +94,11 @@ def get(
     sort,
     endpoint,
     pretty_print,
+    silent,
     include_providers,
     exclude_providers,
     exclude_databases,
+    http_timeout,
 ):
     return _get(
         use_async,
@@ -99,9 +111,11 @@ def get(
         sort,
         endpoint,
         pretty_print,
+        silent,
         include_providers,
         exclude_providers,
         exclude_databases,
+        http_timeout,
     )
 
 
@@ -116,12 +130,13 @@ def _get(
     sort,
     endpoint,
     pretty_print,
+    silent,
     include_providers,
     exclude_providers,
     exclude_databases,
+    http_timeout,
     **kwargs,
 ):
-
     if output_file:
         output_file_path = pathlib.Path(output_file)
         try:
@@ -131,7 +146,7 @@ def _get(
                 f"Desired output file {output_file} already exists, not overwriting."
             )
 
-    client = OptimadeClient(
+    args = dict(
         base_urls=base_url,
         use_async=use_async,
         max_results_per_provider=max_results_per_provider,
@@ -144,6 +159,16 @@ def _get(
         exclude_databases=set(_.strip() for _ in exclude_databases.split(","))
         if exclude_databases
         else None,
+        silent=silent,
+    )
+
+    # Only set http timeout if its not null to avoid overwriting or duplicating the
+    # default value set on the OptimadeClient class
+    if http_timeout:
+        args["http_timeout"] = http_timeout
+
+    client = OptimadeClient(
+        **args,
         **kwargs,
     )
     if response_fields:
